@@ -1,5 +1,5 @@
 /*############################################################################
-  # Copyright (C) 2020 Intel Corporation
+  # Copyright (C) Intel Corporation
   #
   # SPDX-License-Identifier: MIT
   ############################################################################*/
@@ -23,6 +23,8 @@ TEST(Dispatcher_GPU_CreateSession, SetInvalidNumThreadTypeReturnsErrUnsupported)
     Dispatcher_CreateSession_SetInvalidNumThreadTypeReturnsErrUnsupported(MFX_IMPL_TYPE_HARDWARE);
 }
 
+#ifdef ONEVPL_EXPERIMENTAL
+
 // fully-implemented test cases (not using common kernels)
 TEST(Dispatcher_GPU_CreateSession, ExtDeviceID_ValidProps) {
     SKIP_IF_DISP_GPU_DISABLED();
@@ -35,12 +37,12 @@ TEST(Dispatcher_GPU_CreateSession, ExtDeviceID_ValidProps) {
 
     // set valid, basic properties
     SetConfigFilterProperty<mfxU16>(loader, "mfxExtendedDeviceId.VendorID", 0x8086);
-#if defined(_WIN32) || defined(_WIN64)
+    #if defined(_WIN32) || defined(_WIN64)
     SetConfigFilterProperty<mfxU32>(loader, "mfxExtendedDeviceId.LUIDDeviceNodeMask", 1);
-#else
+    #else
     SetConfigFilterProperty<mfxU32>(loader, "mfxExtendedDeviceId.DRMRenderNodeNum", 128);
     SetConfigFilterProperty<mfxU32>(loader, "mfxExtendedDeviceId.DRMPrimaryNodeNum", 0);
-#endif
+    #endif
     // create session with first implementation
     mfxSession session = nullptr;
     sts                = MFXCreateSession(loader, 0, &session);
@@ -63,12 +65,12 @@ TEST(Dispatcher_GPU_CreateSession, ExtDeviceID_InvalidProps) {
 
     // set valid, basic properties
     SetConfigFilterProperty<mfxU16>(loader, "mfxExtendedDeviceId.VendorID", 0x8086);
-#if defined(_WIN32) || defined(_WIN64)
+    #if defined(_WIN32) || defined(_WIN64)
     SetConfigFilterProperty<mfxU32>(loader, "mfxExtendedDeviceId.LUIDDeviceNodeMask", 333);
-#else
+    #else
     SetConfigFilterProperty<mfxU32>(loader, "mfxExtendedDeviceId.DRMRenderNodeNum", 999);
     SetConfigFilterProperty<mfxU32>(loader, "mfxExtendedDeviceId.DRMPrimaryNodeNum", 555);
-#endif
+    #endif
     // create session with first implementation
     mfxSession session = nullptr;
     sts                = MFXCreateSession(loader, 0, &session);
@@ -78,6 +80,8 @@ TEST(Dispatcher_GPU_CreateSession, ExtDeviceID_InvalidProps) {
     MFXUnload(loader);
 }
 
+#endif // ONEVPL_EXPERIMENTAL
+
 TEST(Dispatcher_GPU_CloneSession, Basic_Clone_Succeeds) {
     SKIP_IF_DISP_GPU_VPL_DISABLED();
 
@@ -203,6 +207,47 @@ TEST(Dispatcher_GPU_CloneSession, Double_Clone_Succeeds) {
     MFXUnload(loader);
 }
 
+TEST(Dispatcher_GPU_JoinSession, Basic_Join_Succeeds) {
+    SKIP_IF_DISP_GPU_DISABLED();
+
+    mfxLoader loader = MFXLoad();
+    EXPECT_FALSE(loader == nullptr);
+
+    mfxStatus sts = SetConfigImpl(loader, MFX_IMPL_TYPE_HARDWARE);
+    EXPECT_EQ(sts, MFX_ERR_NONE);
+
+    // require 2.x RT
+    sts = SetConfigFilterProperty<mfxU16>(loader, "mfxImplDescription.ApiVersion.Major", 1);
+    sts = SetConfigFilterProperty<mfxU16>(loader, "mfxImplDescription.ApiVersion.Minor", 0);
+    EXPECT_EQ(sts, MFX_ERR_NONE);
+
+    // create session with first implementation
+    mfxSession session = nullptr;
+    sts                = MFXCreateSession(loader, 0, &session);
+    EXPECT_EQ(sts, MFX_ERR_NONE);
+
+    // create another session with first implementation
+    mfxSession cloneSession = nullptr;
+    sts                     = MFXCreateSession(loader, 0, &cloneSession);
+    EXPECT_EQ(sts, MFX_ERR_NONE);
+
+    sts = MFXJoinSession(session, cloneSession);
+    EXPECT_EQ(sts, MFX_ERR_NONE);
+
+    // disjoin the child (cloned) session
+    sts = MFXDisjoinSession(cloneSession);
+    EXPECT_EQ(sts, MFX_ERR_NONE);
+
+    // free internal resources
+    sts = MFXClose(session);
+    EXPECT_EQ(sts, MFX_ERR_NONE);
+
+    sts = MFXClose(cloneSession);
+    EXPECT_EQ(sts, MFX_ERR_NONE);
+
+    MFXUnload(loader);
+}
+
 #if defined(_WIN32) || defined(_WIN64)
 TEST(Dispatcher_GPU_CreateSession, D3D9CanCreateSession) {
     SKIP_IF_DISP_GPU_MSDK_DISABLED();
