@@ -60,7 +60,7 @@ int open_first_intel_adapter(int type) {
             continue;
 
         if (!get_drm_driver_name(fd, driverName, MFX_DRM_DRIVER_NAME_LEN) &&
-            !strcmp(driverName, MFX_DRM_INTEL_DRIVER_NAME)) {
+            msdk_match(driverName, MFX_DRM_INTEL_DRIVER_NAME)) {
             return fd;
         }
         close(fd);
@@ -76,18 +76,18 @@ int open_intel_adapter(const std::string& devicePath, int type) {
     int fd = open(devicePath.c_str(), O_RDWR);
 
     if (fd < 0) {
-        msdk_printf(MSDK_STRING("Failed to open specified device\n"));
+        printf("Failed to open specified device\n");
         return -1;
     }
 
     char driverName[MFX_DRM_DRIVER_NAME_LEN + 1] = {};
     if (!get_drm_driver_name(fd, driverName, MFX_DRM_DRIVER_NAME_LEN) &&
-        !strcmp(driverName, MFX_DRM_INTEL_DRIVER_NAME)) {
+        msdk_match(driverName, MFX_DRM_INTEL_DRIVER_NAME)) {
         return fd;
     }
     else {
         close(fd);
-        msdk_printf(MSDK_STRING("Specified device is not Intel one\n"));
+        printf("Specified device is not Intel one\n");
         return -1;
     }
 }
@@ -129,12 +129,12 @@ DRMLibVA::~DRMLibVA(void) {
 struct drmMonitorsTable {
     mfxI32 mfx_type;
     uint32_t drm_type;
-    const msdk_char* type_name;
+    const char* type_name;
 };
 
 drmMonitorsTable g_drmMonitorsTable[] = {
     #define __DECLARE(type) \
-        { MFX_MONITOR_##type, DRM_MODE_CONNECTOR_##type, MSDK_STRING(#type) }
+        { MFX_MONITOR_##type, DRM_MODE_CONNECTOR_##type, #type }
     __DECLARE(Unknown),   __DECLARE(VGA),       __DECLARE(DVII),        __DECLARE(DVID),
     __DECLARE(DVIA),      __DECLARE(Composite), __DECLARE(SVIDEO),      __DECLARE(LVDS),
     __DECLARE(Component), __DECLARE(9PinDIN),   __DECLARE(HDMIA),       __DECLARE(HDMIB),
@@ -157,17 +157,27 @@ uint32_t drmRenderer::getConnectorType(mfxI32 monitor_type) {
     return DRM_MODE_CONNECTOR_Unknown;
 }
 
-const msdk_char* drmRenderer::getConnectorName(uint32_t connector_type) {
+const char* drmRenderer::getConnectorName(uint32_t connector_type) {
     for (size_t i = 0; i < sizeof(g_drmMonitorsTable) / sizeof(g_drmMonitorsTable[0]); ++i) {
         if (g_drmMonitorsTable[i].drm_type == connector_type) {
             return g_drmMonitorsTable[i].type_name;
         }
     }
-    return MSDK_STRING("Unknown");
+    return "Unknown";
 }
 
 drmRenderer::drmRenderer(int fd, mfxI32 monitorType)
         : m_fd(fd),
+          m_connector_type(),
+          m_connectorID(),
+          m_encoderID(),
+          m_crtcID(),
+          m_crtcIndex(),
+          m_planeID(),
+          m_mode(),
+          m_crtc(),
+          m_connectorProperties(),
+          m_crtcProperties(),
           m_bufmgr(NULL),
           m_overlay_wrn(true),
           m_bSentHDR(false),
@@ -199,11 +209,11 @@ drmRenderer::drmRenderer(int fd, mfxI32 monitorType)
     if (!res) {
         throw std::invalid_argument("Failed to allocate renderer");
     }
-    msdk_printf(MSDK_STRING("drmrender: connected via %s to %dx%d@%d capable display\n"),
-                getConnectorName(m_connector_type),
-                m_mode.hdisplay,
-                m_mode.vdisplay,
-                m_mode.vrefresh);
+    printf("drmrender: connected via %s to %dx%d@%d capable display\n",
+           getConnectorName(m_connector_type),
+           m_mode.hdisplay,
+           m_mode.vdisplay,
+           m_mode.vrefresh);
 
     drmSetColorSpace(false);
     drmSendHdrMetaData(NULL, NULL, false);
@@ -239,7 +249,7 @@ uint32_t drmRenderer::getCRTCPropertyId(const char* propNameToFind) {
     uint32_t i, id = 0;
     for (i = 0; i < m_crtcProperties->count_props; i++) {
         property = m_drmlib.drmModeGetProperty(m_fd, m_crtcProperties->props[i]);
-        if (!strcmp(property->name, propNameToFind))
+        if (msdk_match(property->name, propNameToFind))
             id = property->prop_id;
 
         m_drmlib.drmModeFreeProperty(property);
@@ -266,20 +276,20 @@ bool drmRenderer::getConnector(drmModeRes* resource, uint32_t connector_type) {
             if ((connector->connector_type == connector_type) ||
                 (connector_type == DRM_MODE_CONNECTOR_Unknown)) {
                 if (connector->connection == DRM_MODE_CONNECTED) {
-                    msdk_printf(MSDK_STRING("drmrender: trying connection: %s\n"),
-                                getConnectorName(connector->connector_type));
+                    printf("drmrender: trying connection: %s\n",
+                           getConnectorName(connector->connector_type));
                     m_connector_type = connector->connector_type;
                     m_connectorID    = connector->connector_id;
                     m_connectorProperties =
                         getProperties(m_fd, m_connectorID, DRM_MODE_OBJECT_CONNECTOR);
                     found = setupConnection(resource, connector);
                     if (found)
-                        msdk_printf(MSDK_STRING("drmrender: succeeded...\n"));
+                        printf("drmrender: succeeded...\n");
                     else
-                        msdk_printf(MSDK_STRING("drmrender: failed...\n"));
+                        printf("drmrender: failed...\n");
                 }
                 else if ((connector_type != DRM_MODE_CONNECTOR_Unknown)) {
-                    msdk_printf(MSDK_STRING("drmrender: error: requested monitor not connected\n"));
+                    printf("drmrender: error: requested monitor not connected\n");
                 }
             }
             m_drmlib.drmModeFreeConnector(connector);
@@ -287,7 +297,7 @@ bool drmRenderer::getConnector(drmModeRes* resource, uint32_t connector_type) {
                 return true;
         }
     }
-    msdk_printf(MSDK_STRING("drmrender: error: requested monitor not available\n"));
+    printf("drmrender: error: requested monitor not available\n");
     return found;
 }
 
@@ -296,7 +306,7 @@ bool drmRenderer::drmDisplayHasHdr(const uint8_t* edid) {
     const uint8_t* hdrDb;
 
     if (!edid) {
-        msdk_printf(MSDK_STRING("drmrender: invalid EDID\n"));
+        printf("drmrender: invalid EDID\n");
         return false;
     }
 
@@ -321,13 +331,13 @@ const uint8_t* drmRenderer::edidFindExtendedDataBlock(const uint8_t* edid,
     const uint8_t* ceaExtBlk;
 
     if (!edid) {
-        msdk_printf(MSDK_STRING("drmrender: no EDID in blob\n"));
+        printf("drmrender: no EDID in blob\n");
         return NULL;
     }
 
     ceaExtBlk = edidFindCeaExtensionBlock(edid);
     if (!ceaExtBlk) {
-        msdk_printf(MSDK_STRING("drmrender: no CEA extension block available\n"));
+        printf("drmrender: no CEA extension block available\n");
         return NULL;
     }
 
@@ -363,13 +373,13 @@ const uint8_t* drmRenderer::edidFindCeaExtensionBlock(const uint8_t* edid) {
     const uint8_t* ext = NULL;
 
     if (!edid) {
-        msdk_printf(MSDK_STRING("drmrender: no EDID\n"));
+        printf("drmrender: no EDID\n");
         return NULL;
     }
 
     ext_blks = edid[126];
     if (!ext_blks) {
-        msdk_printf(MSDK_STRING("drmrender: EDID doesn't have any extension block\n"));
+        printf("drmrender: EDID doesn't have any extension block\n");
         return NULL;
     }
 
@@ -392,8 +402,8 @@ bool drmRenderer::setupConnection(drmModeRes* resource, drmModeConnector* connec
     drmModePropertyBlobRes* edidBlob;
 
     if (!connector->count_modes) {
-        msdk_printf(MSDK_STRING("drmrender: error: no valid modes for %s connector\n"),
-                    getConnectorName(connector->connector_type));
+        printf("drmrender: error: no valid modes for %s connector\n",
+               getConnectorName(connector->connector_type));
         return false;
     }
 
@@ -421,7 +431,7 @@ bool drmRenderer::setupConnection(drmModeRes* resource, drmModeConnector* connec
             }
         }
         ret = true;
-        msdk_printf(MSDK_STRING("drmrender: selected crtc already attached to connector\n"));
+        printf("drmrender: selected crtc already attached to connector\n");
         m_drmlib.drmModeFreeEncoder(encoder);
     }
 
@@ -441,7 +451,7 @@ bool drmRenderer::setupConnection(drmModeRes* resource, drmModeConnector* connec
                     m_crtcIndex = j;
                     m_crtcID    = resource->crtcs[j];
                     ret         = true;
-                    msdk_printf(MSDK_STRING("drmrender: found crtc with global search\n"));
+                    printf("drmrender: found crtc with global search\n");
                     break;
                 }
                 m_drmlib.drmModeFreeEncoder(encoder);
@@ -456,7 +466,7 @@ bool drmRenderer::setupConnection(drmModeRes* resource, drmModeConnector* connec
             ret = false;
     }
     else {
-        msdk_printf(MSDK_STRING("drmrender: failed to select crtc\n"));
+        printf("drmrender: failed to select crtc\n");
     }
     return ret;
 }
@@ -498,8 +508,7 @@ bool drmRenderer::setMaster() {
         usleep(100);
         ++wait_count;
     } while (wait_count < 30000);
-    msdk_printf(MSDK_STRING(
-        "drmrender: error: failed to get drm mastership during 3 seconds - aborting\n"));
+    printf("drmrender: error: failed to get drm mastership during 3 seconds - aborting\n");
     return false;
 }
 
@@ -520,7 +529,7 @@ bool drmRenderer::restore() {
                                       1,
                                       &m_mode);
     if (ret) {
-        msdk_printf(MSDK_STRING("drmrender: failed to restore original mode\n"));
+        printf("drmrender: failed to restore original mode\n");
         return false;
     }
     dropMaster();
@@ -541,7 +550,7 @@ uint32_t drmRenderer::getConnectorPropertyId(const char* propNameToFind) {
         property = m_drmlib.drmModeGetProperty(m_fd, m_connectorProperties->props[i]);
         if (!property)
             continue;
-        if (!strcmp(property->name, propNameToFind))
+        if (msdk_match(property->name, propNameToFind))
             id = property->prop_id;
 
         m_drmlib.drmModeFreeProperty(property);
@@ -568,7 +577,7 @@ uint32_t drmRenderer::getConnectorPropertyValue(const char* propNameToFind) {
         property = m_drmlib.drmModeGetProperty(m_fd, m_connectorProperties->props[i]);
         if (!property)
             continue;
-        if (!strcmp(property->name, propNameToFind))
+        if (msdk_match(property->name, propNameToFind))
             value = m_connectorProperties->prop_values[i];
 
         m_drmlib.drmModeFreeProperty(property);
@@ -639,12 +648,12 @@ int drmRenderer::drmSendHdrMetaData(mfxExtMasteringDisplayColourVolume* displayC
                     displayColor->DisplayPrimariesY[2];
                 m_hdrMetaData.data.hdmi_metadata_type1.white_point.x = displayColor->WhitePointX;
                 m_hdrMetaData.data.hdmi_metadata_type1.white_point.y = displayColor->WhitePointY;
-            }
-            if (contentLight->InsertPayloadToggle == MFX_PAYLOAD_IDR) {
+                m_hdrMetaData.data.hdmi_metadata_type1.max_display_mastering_luminance =
+                    displayColor->MaxDisplayMasteringLuminance / 10000;
                 m_hdrMetaData.data.hdmi_metadata_type1.min_display_mastering_luminance =
                     displayColor->MinDisplayMasteringLuminance;
-                m_hdrMetaData.data.hdmi_metadata_type1.max_display_mastering_luminance =
-                    displayColor->MaxDisplayMasteringLuminance;
+            }
+            if (contentLight->InsertPayloadToggle == MFX_PAYLOAD_IDR) {
                 m_hdrMetaData.data.hdmi_metadata_type1.max_cll = contentLight->MaxContentLightLevel;
                 m_hdrMetaData.data.hdmi_metadata_type1.max_fall =
                     contentLight->MaxPicAverageLightLevel;
@@ -747,7 +756,7 @@ void* drmRenderer::acquire(mfxMemId mid) {
             set_tiling.stride      = vmid->m_image.pitches[0];
             ret = m_drmlib.drmIoctl(m_fd, DRM_IOCTL_I915_GEM_SET_TILING, &set_tiling);
             if (ret) {
-                msdk_printf(MSDK_STRING("DRM_IOCTL_I915_GEM_SET_TILING Failed ret = %d\n"), ret);
+                printf("DRM_IOCTL_I915_GEM_SET_TILING Failed ret = %d\n", ret);
                 return NULL;
             }
 
@@ -798,8 +807,8 @@ void drmRenderer::release(mfxMemId mid, void* mem) {
     if (!hdl)
         return;
     if (!restore()) {
-        msdk_printf(MSDK_STRING(
-            "drmrender: warning: failure to restore original mode may lead to application segfault!\n"));
+        printf(
+            "drmrender: warning: failure to restore original mode may lead to application segfault!\n");
     }
     m_drmlib.drmModeRmFB(m_fd, *hdl);
     delete (hdl);
@@ -832,7 +841,7 @@ mfxStatus drmRenderer::render(mfxFrameSurface1* pSurface) {
     else {
         if (m_overlay_wrn) {
             m_overlay_wrn = false;
-            msdk_printf(MSDK_STRING("drmrender: warning: rendering via OVERLAY plane\n"));
+            printf("drmrender: warning: rendering via OVERLAY plane\n");
         }
     // to support direct panel tonemap for 8K@60 HDR playback via CH7218 connected
     // to 8K HDR panel.
