@@ -14,10 +14,11 @@
 
 #include "pipeline_transcode.h"
 #include "sample_utils.h"
-#include "transcode_utils.h"
+#include "smt_cli.h"
 #include "vpl_implementation_loader.h"
 
 #include <memory>
+#include <vector>
 #include "d3d11_allocator.h"
 #include "d3d11_device.h"
 #include "d3d_allocator.h"
@@ -35,6 +36,7 @@
 #ifndef MFX_VERSION
     #error MFX_VERSION not defined
 #endif
+#include "smt_cli_params.h"
 
 namespace TranscodingSample {
 class Launcher {
@@ -42,7 +44,7 @@ public:
     Launcher();
     virtual ~Launcher();
 
-    virtual mfxStatus Init(int argc, msdk_char* argv[]);
+    virtual mfxStatus Init(int argc, char* argv[]);
     virtual void Run();
     virtual mfxStatus ProcessResult();
 
@@ -64,7 +66,9 @@ protected:
     virtual void Close();
 
     // command line parser
-    CmdProcessor m_parser;
+    std::string performance_file_name;
+    std::string parameter_file_name;
+    std::vector<std::string> session_descriptions;
     // threads contexts to process playlist
     std::vector<std::unique_ptr<ThreadTranscodeContext>> m_pThreadContextArray;
     // allocator for each session
